@@ -20,6 +20,7 @@ from openstack import exceptions as os_exc
 import requests
 
 from metalsmith import _instance
+from metalsmith import _network_metadata
 from metalsmith import _provisioner
 from metalsmith import _utils
 from metalsmith import exceptions
@@ -510,6 +511,12 @@ class TestProvisionNode(Base):
         self.configdrive_mock = configdrive_patcher.start()
         self.addCleanup(configdrive_patcher.stop)
 
+        create_network_metadata_patches = mock.patch.object(
+            _network_metadata, 'create_network_metadata', autospec=True
+        )
+        self.network_metadata_mock = create_network_metadata_patches.start()
+        self.addCleanup(create_network_metadata_patches.stop)
+
         self.api.baremetal.get_node.side_effect = lambda _n: self.node
         self.api.baremetal.get_allocation.side_effect = (
             lambda _a: self.allocation)
@@ -531,7 +538,8 @@ class TestProvisionNode(Base):
             self.node, instance_info=self.instance_info, extra=self.extra)
         self.api.baremetal.validate_node.assert_called_once_with(self.node)
         self.configdrive_mock.assert_called_once_with(mock.ANY, self.node,
-                                                      self.allocation.name)
+                                                      self.allocation.name,
+                                                      mock.ANY)
         self.api.baremetal.set_node_provision_state.assert_called_once_with(
             self.node, 'active', config_drive=mock.ANY)
         self.assertFalse(self.api.network.delete_port.called)
@@ -553,7 +561,7 @@ class TestProvisionNode(Base):
             self.node, instance_info=self.instance_info, extra=self.extra)
         self.api.baremetal.validate_node.assert_called_once_with(self.node)
         self.configdrive_mock.assert_called_once_with(mock.ANY, self.node,
-                                                      self.node.name)
+                                                      self.node.name, mock.ANY)
         self.api.baremetal.set_node_provision_state.assert_called_once_with(
             self.node, 'active', config_drive=mock.ANY)
         self.assertFalse(self.api.network.delete_port.called)
@@ -610,7 +618,7 @@ class TestProvisionNode(Base):
         self.assertEqual(inst.node, self.node)
 
         config.generate.assert_called_once_with(self.node,
-                                                self.allocation.name)
+                                                self.allocation.name, mock.ANY)
         self.api.network.create_port.assert_called_once_with(
             network_id=self.api.network.find_network.return_value.id,
             name='example.com-%s' %
@@ -660,7 +668,7 @@ class TestProvisionNode(Base):
             self.node, instance_info=self.instance_info, extra=self.extra)
         self.api.baremetal.validate_node.assert_called_once_with(self.node)
         self.configdrive_mock.assert_called_once_with(mock.ANY, self.node,
-                                                      hostname)
+                                                      hostname, mock.ANY)
         self.api.baremetal.set_node_provision_state.assert_called_once_with(
             self.node, 'active', config_drive=mock.ANY)
         self.assertFalse(
@@ -688,7 +696,7 @@ class TestProvisionNode(Base):
             self.node, instance_info=self.instance_info, extra=self.extra)
         self.api.baremetal.validate_node.assert_called_once_with(self.node)
         self.configdrive_mock.assert_called_once_with(mock.ANY, self.node,
-                                                      hostname)
+                                                      hostname, mock.ANY)
         self.api.baremetal.set_node_provision_state.assert_called_once_with(
             self.node, 'active', config_drive=mock.ANY)
         self.assertFalse(
@@ -718,7 +726,7 @@ class TestProvisionNode(Base):
             self.node, instance_info=self.instance_info, extra=self.extra)
         self.api.baremetal.validate_node.assert_called_once_with(self.node)
         self.configdrive_mock.assert_called_once_with(mock.ANY, self.node,
-                                                      hostname)
+                                                      hostname, mock.ANY)
         self.api.baremetal.set_node_provision_state.assert_called_once_with(
             self.node, 'active', config_drive=mock.ANY)
         self.assertFalse(
@@ -775,7 +783,7 @@ class TestProvisionNode(Base):
             self.node, extra=self.extra, instance_info=self.instance_info)
         self.api.baremetal.validate_node.assert_called_once_with(self.node)
         self.configdrive_mock.assert_called_once_with(mock.ANY, self.node,
-                                                      self.node.name)
+                                                      self.node.name, mock.ANY)
         self.api.baremetal.set_node_provision_state.assert_called_once_with(
             self.node, 'active', config_drive=mock.ANY)
         self.assertFalse(
@@ -808,7 +816,7 @@ class TestProvisionNode(Base):
             self.node, extra=self.extra, instance_info=self.instance_info)
         self.api.baremetal.validate_node.assert_called_once_with(self.node)
         self.configdrive_mock.assert_called_once_with(mock.ANY, self.node,
-                                                      self.node.id)
+                                                      self.node.id, mock.ANY)
         self.api.baremetal.set_node_provision_state.assert_called_once_with(
             self.node, 'active', config_drive=mock.ANY)
         self.assertFalse(
@@ -1837,7 +1845,7 @@ class TestUnprovisionNode(Base):
         self.assertFalse(
             self.api.baremetal.wait_for_nodes_provision_state.called)
         self.api.baremetal.update_node.assert_called_once_with(
-            self.node, instance_info={}, extra={'foo': 'bar'})
+            self.node, extra={'foo': 'bar'})
         self.assertFalse(self.api.baremetal.delete_allocation.called)
         # We cannot delete an allocation for an active node, it will be deleted
         # automatically.
@@ -1859,7 +1867,7 @@ class TestUnprovisionNode(Base):
         self.assertFalse(
             self.api.baremetal.wait_for_nodes_provision_state.called)
         self.api.baremetal.update_node.assert_called_once_with(
-            self.node, instance_info={}, extra={'foo': 'bar'})
+            self.node, extra={'foo': 'bar'})
         self.api.baremetal.delete_allocation.assert_called_once_with('123')
 
     def test_with_attached(self):
@@ -1876,7 +1884,7 @@ class TestUnprovisionNode(Base):
         self.assertFalse(
             self.api.baremetal.wait_for_nodes_provision_state.called)
         self.api.baremetal.update_node.assert_called_once_with(
-            self.node, instance_info={}, extra={})
+            self.node, extra={})
 
     def test_with_wait(self):
         result = self.pr.unprovision_node(self.node, wait=3600)
@@ -1889,7 +1897,7 @@ class TestUnprovisionNode(Base):
         self.api.baremetal.set_node_provision_state.assert_called_once_with(
             self.node, 'deleted', wait=False)
         self.api.baremetal.update_node.assert_called_once_with(
-            self.node, instance_info={}, extra={})
+            self.node, extra={})
         wait_mock = self.api.baremetal.wait_for_nodes_provision_state
         wait_mock.assert_called_once_with([self.node], 'available',
                                           timeout=3600)
@@ -1920,7 +1928,7 @@ class TestUnprovisionNode(Base):
         self.assertFalse(
             self.api.baremetal.wait_for_nodes_provision_state.called)
         self.api.baremetal.update_node.assert_called_once_with(
-            self.node, instance_info={}, extra={'foo': 'bar'},
+            self.node, extra={'foo': 'bar'},
             instance_id=None)
         self.assertFalse(self.api.baremetal.delete_allocation.called)
 
